labeller

package
v0.0.0-...-1c6d3df Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (

	// AppLabel refers to application of the Kubernetes Object
	AppLabel = "app"
)

Variables

This section is empty.

Functions

func BuildLabels

func BuildLabels(r KubernetesLabelsRequest) map[string]string

BuildLabels builds the labels for the Kubernetes object Combines resource labels with project labels

func BuildNamespaceLabels

func BuildNamespaceLabels(r KubernetesLabelsRequest) map[string]string

BuildNamespaceLabels builds the labels for a Kubernetes namespace. Combines resource labels with project labels

func GetLabelName

func GetLabelName(name string) string

GetLabelName prefixes the label with the config specified label and returns the formatted label name

func GetNamespaceLabelName

func GetNamespaceLabelName(name string) string

GetNamespaceLabelName prefixes the label with the specified label and returns the formatted label name

func InitKubernetesLabeller

func InitKubernetesLabeller(p, ns, e string)

InitKubernetesLabeller builds a new KubernetesLabeller Singleton

Types

type KubernetesLabelsRequest

type KubernetesLabelsRequest struct {
	Stream string
	Team   string
	App    string
	Labels []mlp.Label
}

KubernetesLabelsRequest helps to build the Kubernetes labels needed for Kubernetes objects.

Jump to