database

package
v0.0.0-...-1c6d3df Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InitDB

func InitDB(cfg *config.DatabaseConfig) (*gorm.DB, error)

InitDB initialises a database connection as well as runs the migration scripts. It is important to close the database after using it by calling defer db.Close()

Types

This section is empty.

Jump to