mocks

package
v0.0.0-...-1c6d3df Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2025 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ExperimentManager

type ExperimentManager struct {
	mock.Mock
}

ExperimentManager is an autogenerated mock type for the ExperimentManager type

func (*ExperimentManager) GetEngineInfo

func (_m *ExperimentManager) GetEngineInfo() (manager.Engine, error)

GetEngineInfo provides a mock function with given fields:

func (*ExperimentManager) GetExperimentRunnerConfig

func (_m *ExperimentManager) GetExperimentRunnerConfig(cfg json.RawMessage) (json.RawMessage, error)

GetExperimentRunnerConfig provides a mock function with given fields: cfg

func (*ExperimentManager) ValidateExperimentConfig

func (_m *ExperimentManager) ValidateExperimentConfig(cfg json.RawMessage) error

ValidateExperimentConfig provides a mock function with given fields: cfg

type StandardExperimentManager

type StandardExperimentManager struct {
	mock.Mock
}

StandardExperimentManager is an autogenerated mock type for the StandardExperimentManager type

func (*StandardExperimentManager) GetEngineInfo

func (_m *StandardExperimentManager) GetEngineInfo() (manager.Engine, error)

GetEngineInfo provides a mock function with given fields:

func (*StandardExperimentManager) GetExperimentRunnerConfig

func (_m *StandardExperimentManager) GetExperimentRunnerConfig(cfg json.RawMessage) (json.RawMessage, error)

GetExperimentRunnerConfig provides a mock function with given fields: cfg

func (*StandardExperimentManager) IsCacheEnabled

func (_m *StandardExperimentManager) IsCacheEnabled() (bool, error)

IsCacheEnabled provides a mock function with given fields:

func (*StandardExperimentManager) ListClients

func (_m *StandardExperimentManager) ListClients() ([]manager.Client, error)

ListClients provides a mock function with given fields:

func (*StandardExperimentManager) ListExperiments

func (_m *StandardExperimentManager) ListExperiments() ([]manager.Experiment, error)

ListExperiments provides a mock function with given fields:

func (*StandardExperimentManager) ListExperimentsForClient

func (_m *StandardExperimentManager) ListExperimentsForClient(_a0 manager.Client) ([]manager.Experiment, error)

ListExperimentsForClient provides a mock function with given fields: _a0

func (*StandardExperimentManager) ListVariablesForClient

func (_m *StandardExperimentManager) ListVariablesForClient(_a0 manager.Client) ([]manager.Variable, error)

ListVariablesForClient provides a mock function with given fields: _a0

func (*StandardExperimentManager) ListVariablesForExperiments

func (_m *StandardExperimentManager) ListVariablesForExperiments(_a0 []manager.Experiment) (map[string][]manager.Variable, error)

ListVariablesForExperiments provides a mock function with given fields: _a0

func (*StandardExperimentManager) ValidateExperimentConfig

func (_m *StandardExperimentManager) ValidateExperimentConfig(cfg json.RawMessage) error

ValidateExperimentConfig provides a mock function with given fields: cfg

Jump to