shared

package
v0.0.0-...-1c6d3df Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2025 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Configurable

type Configurable interface {
	Configure(cfg json.RawMessage) error
}

Configurable interface can be implemented by plugins that require to be configured with a JSON config data

type RPCClient

type RPCClient interface {
	Call(serviceMethod string, args interface{}, reply interface{}) error
}

RPCClient is a minimal interface to describe *rpc.Client implementation Used to simplify mocking of the *rpc.Client in unit tests

Jump to