Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
InConditionOperator = RuleConditionOperator{&inConditionOperator{}}
)
Functions ¶
This section is empty.
Types ¶
type RuleConditionOperator ¶
type RuleConditionOperator struct {
Operator
}
func (RuleConditionOperator) MarshalJSON ¶
func (o RuleConditionOperator) MarshalJSON() ([]byte, error)
func (RuleConditionOperator) String ¶
func (o RuleConditionOperator) String() string
func (*RuleConditionOperator) UnmarshalJSON ¶
func (o *RuleConditionOperator) UnmarshalJSON(data []byte) error
type TrafficRuleCondition ¶
type TrafficRuleCondition struct {
FieldSource request.FieldSource `json:"field_source" validate:"required,oneof=header payload prediction_context"`
Field string `json:"field" validate:"required"`
Operator RuleConditionOperator `json:"operator" validate:"required,oneof=in"`
Values []string `json:"values" validate:"required,notBlank"`
}
func (*TrafficRuleCondition) TestRequest ¶
func (c *TrafficRuleCondition) TestRequest(req fiber.Request) (bool, error)
TestRequest test that the request satisfy the traffic rule condition
func (*TrafficRuleCondition) TestUPIRequest ¶
func (c *TrafficRuleCondition) TestUPIRequest(req *upiv1.PredictValuesRequest, header metadata.MD) (bool, error)
TestUPIRequest test that the UPI request satisfy the traffic rule condition
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
command
|
|
|
errors
Package errors provides definitions for some common errors that may be encountered through the course of the turning mission control's functions.
|
Package errors provides definitions for some common errors that may be encountered through the course of the turning mission control's functions. |
|
fiberapi/internal/testutils
Package testutils contains mocks that can be shared across tests for multiple packages
|
Package testutils contains mocks that can be shared across tests for multiple packages |
Click to show internal directories.
Click to hide internal directories.