Documentation
¶
Index ¶
- Constants
- func BuildLabels(r KubernetesLabelsRequest) map[string]string
- func BuildNamespaceLabels(r KubernetesLabelsRequest) map[string]string
- func GetLabelName(name string) string
- func GetNamespaceLabelName(name string) string
- func InitKubernetesLabeller(p, ns, e string)
- func IsValidLabel(name string) error
- type KubernetesLabelsRequest
Constants ¶
const (
// AppLabel refers to application of the Kubernetes Object
AppLabel = "app"
)
Variables ¶
This section is empty.
Functions ¶
func BuildLabels ¶
func BuildLabels(r KubernetesLabelsRequest) map[string]string
BuildLabels builds the labels for the Kubernetes object Combines resource labels with project labels
func BuildNamespaceLabels ¶
func BuildNamespaceLabels(r KubernetesLabelsRequest) map[string]string
BuildNamespaceLabels builds the labels for a Kubernetes namespace. Combines resource labels with project labels
func GetLabelName ¶
GetLabelName prefixes the label with the config specified label and returns the formatted label name
func GetNamespaceLabelName ¶
GetNamespaceLabelName prefixes the label with the specified label and returns the formatted label name
func InitKubernetesLabeller ¶
func InitKubernetesLabeller(p, ns, e string)
InitKubernetesLabeller builds a new KubernetesLabeller Singleton
func IsValidLabel ¶
ValidLabel logic reused from https://github.com/caraml-dev/merlin/blob/06f121c6da05c5b5f1a28389e1078aaafed67541/api/models/metadata.go#L57
Types ¶
Click to show internal directories.
Click to hide internal directories.