Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EngineConfig ¶
type EngineConfig struct {
PluginBinary string `mapstructure:"plugin_binary"`
EngineConfiguration map[string]interface{} `mapstructure:",remain"`
}
EngineConfig is a struct used to decode engine's configuration into It consists of an optional PluginBinary (if the experiment engine is implemented as net/rpc plugin) and unstructured EngineConfiguration of key/value data, that is used to configure experiment manager/runner
func (EngineConfig) IsPlugin ¶
func (c EngineConfig) IsPlugin() bool
func (EngineConfig) RawEngineConfig ¶
func (c EngineConfig) RawEngineConfig() (json.RawMessage, error)
Click to show internal directories.
Click to hide internal directories.