Documentation
¶
Index ¶
- Variables
- type Request
- type Response
- func (*Response) Descriptor() ([]byte, []int)deprecated
- func (x *Response) GetError() string
- func (x *Response) GetHeader() map[string]string
- func (x *Response) GetResponse() string
- func (*Response) ProtoMessage()
- func (x *Response) ProtoReflect() protoreflect.Message
- func (x *Response) Reset()
- func (x *Response) String() string
- type TuringResultLogKey
- func (*TuringResultLogKey) Descriptor() ([]byte, []int)deprecated
- func (x *TuringResultLogKey) GetEventTimestamp() *timestamppb.Timestamp
- func (x *TuringResultLogKey) GetTuringReqId() string
- func (*TuringResultLogKey) ProtoMessage()
- func (x *TuringResultLogKey) ProtoReflect() protoreflect.Message
- func (x *TuringResultLogKey) Reset()
- func (x *TuringResultLogKey) String() string
- type TuringResultLogMessage
- func (*TuringResultLogMessage) Descriptor() ([]byte, []int)deprecated
- func (x *TuringResultLogMessage) GetEnricher() *Response
- func (x *TuringResultLogMessage) GetEnsembler() *Response
- func (x *TuringResultLogMessage) GetEventTimestamp() *timestamppb.Timestamp
- func (x *TuringResultLogMessage) GetExperiment() *Response
- func (x *TuringResultLogMessage) GetRequest() *Request
- func (x *TuringResultLogMessage) GetRouter() *Response
- func (x *TuringResultLogMessage) GetRouterVersion() string
- func (x *TuringResultLogMessage) GetTuringReqId() string
- func (*TuringResultLogMessage) ProtoMessage()
- func (x *TuringResultLogMessage) ProtoReflect() protoreflect.Message
- func (x *TuringResultLogMessage) Reset()
- func (x *TuringResultLogMessage) String() string
Constants ¶
This section is empty.
Variables ¶
var File_TuringResultLog_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Request ¶
type Request struct {
// The header from the incoming request to the Turing router. The map value is a comma-delimited string.
Header map[string]string `` /* 153-byte string literal not displayed */
// The JSON body of the request to the Turing router, UTF-8-encoded
Body string `protobuf:"bytes,2,opt,name=body,proto3" json:"body,omitempty"`
// contains filtered or unexported fields
}
func (*Request) Descriptor
deprecated
func (*Request) ProtoMessage ¶
func (*Request) ProtoMessage()
func (*Request) ProtoReflect ¶
func (x *Request) ProtoReflect() protoreflect.Message
type Response ¶
type Response struct {
// The JSON response from a Turing component (Enricher / Experiment Engine / Router / Ensembler), UTF-8-encoded.
Response string `protobuf:"bytes,1,opt,name=response,proto3" json:"response,omitempty"`
// The error from a Turing component, when a successful response is not received.
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// The response header from a Turing component (Enricher / Experiment Engine / Router / Ensembler); the map value
// is a comma-delimited string.
Header map[string]string `` /* 153-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Response) Descriptor
deprecated
func (*Response) GetResponse ¶
func (*Response) ProtoMessage ¶
func (*Response) ProtoMessage()
func (*Response) ProtoReflect ¶
func (x *Response) ProtoReflect() protoreflect.Message
type TuringResultLogKey ¶
type TuringResultLogKey struct {
// The unique request id generated by Turing, for every incoming request to the Turing router
TuringReqId string `protobuf:"bytes,1,opt,name=turing_req_id,json=turingReqId,proto3" json:"turing_req_id,omitempty"`
// The time at which the final response from the Turing router is generated
EventTimestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=event_timestamp,json=eventTimestamp,proto3" json:"event_timestamp,omitempty"`
// contains filtered or unexported fields
}
key
func (*TuringResultLogKey) Descriptor
deprecated
func (*TuringResultLogKey) Descriptor() ([]byte, []int)
Deprecated: Use TuringResultLogKey.ProtoReflect.Descriptor instead.
func (*TuringResultLogKey) GetEventTimestamp ¶
func (x *TuringResultLogKey) GetEventTimestamp() *timestamppb.Timestamp
func (*TuringResultLogKey) GetTuringReqId ¶
func (x *TuringResultLogKey) GetTuringReqId() string
func (*TuringResultLogKey) ProtoMessage ¶
func (*TuringResultLogKey) ProtoMessage()
func (*TuringResultLogKey) ProtoReflect ¶
func (x *TuringResultLogKey) ProtoReflect() protoreflect.Message
func (*TuringResultLogKey) Reset ¶
func (x *TuringResultLogKey) Reset()
func (*TuringResultLogKey) String ¶
func (x *TuringResultLogKey) String() string
type TuringResultLogMessage ¶
type TuringResultLogMessage struct {
// The unique request id generated by Turing, for every incoming request to the Turing router
TuringReqId string `protobuf:"bytes,1,opt,name=turing_req_id,json=turingReqId,proto3" json:"turing_req_id,omitempty"`
// The time at which the final response from the Turing router is generated
EventTimestamp *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=event_timestamp,json=eventTimestamp,proto3" json:"event_timestamp,omitempty"`
// The version of the router deployed. This corresponds to the name and version of the router deployed from the Turing app.
// Format: {router_name}-{router_version}.{project_name}
RouterVersion string `protobuf:"bytes,3,opt,name=router_version,json=routerVersion,proto3" json:"router_version,omitempty"`
// The original request to the Turing router
Request *Request `protobuf:"bytes,4,opt,name=request,proto3" json:"request,omitempty"`
// The response from the Experiment engine, if configured
Experiment *Response `protobuf:"bytes,5,opt,name=experiment,proto3" json:"experiment,omitempty"`
// The response from the Enricher, if configured
Enricher *Response `protobuf:"bytes,6,opt,name=enricher,proto3" json:"enricher,omitempty"`
// The response from the routes
Router *Response `protobuf:"bytes,7,opt,name=router,proto3" json:"router,omitempty"`
// The response from the Enricher, if configured
Ensembler *Response `protobuf:"bytes,8,opt,name=ensembler,proto3" json:"ensembler,omitempty"`
// contains filtered or unexported fields
}
message
func (*TuringResultLogMessage) Descriptor
deprecated
func (*TuringResultLogMessage) Descriptor() ([]byte, []int)
Deprecated: Use TuringResultLogMessage.ProtoReflect.Descriptor instead.
func (*TuringResultLogMessage) GetEnricher ¶
func (x *TuringResultLogMessage) GetEnricher() *Response
func (*TuringResultLogMessage) GetEnsembler ¶
func (x *TuringResultLogMessage) GetEnsembler() *Response
func (*TuringResultLogMessage) GetEventTimestamp ¶
func (x *TuringResultLogMessage) GetEventTimestamp() *timestamppb.Timestamp
func (*TuringResultLogMessage) GetExperiment ¶
func (x *TuringResultLogMessage) GetExperiment() *Response
func (*TuringResultLogMessage) GetRequest ¶
func (x *TuringResultLogMessage) GetRequest() *Request
func (*TuringResultLogMessage) GetRouter ¶
func (x *TuringResultLogMessage) GetRouter() *Response
func (*TuringResultLogMessage) GetRouterVersion ¶
func (x *TuringResultLogMessage) GetRouterVersion() string
func (*TuringResultLogMessage) GetTuringReqId ¶
func (x *TuringResultLogMessage) GetTuringReqId() string
func (*TuringResultLogMessage) ProtoMessage ¶
func (*TuringResultLogMessage) ProtoMessage()
func (*TuringResultLogMessage) ProtoReflect ¶
func (x *TuringResultLogMessage) ProtoReflect() protoreflect.Message
func (*TuringResultLogMessage) Reset ¶
func (x *TuringResultLogMessage) Reset()
func (*TuringResultLogMessage) String ¶
func (x *TuringResultLogMessage) String() string
Click to show internal directories.
Click to hide internal directories.