Documentation
¶
Index ¶
Constants ¶
const (
// TuringTreatmentChannelKey is used to store a channel to send experiment treatment
TuringTreatmentChannelKey ctxKeyType
)
Variables ¶
This section is empty.
Functions ¶
func GetKeyValsFromContext ¶
GetKeyValsFromContext retrieves all the possible turing related key-value(s) from the input context as a interface{} slice.
func GetRequestID ¶
GetRequestID returns the request id from the input context
func NewTuringContext ¶
NewTuringContext returns a context which holds additional data pertaining to the unique turing request.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.